@@ -66,6 +66,18 @@ alignment ::
 alignment = St.alignment . elementType
 
 {-# INLINE sizeOf #-}
+{- |
+Warning:
+It uses Foldable class and will certainly access the data structure
+and thus will fail on 'undefined'.
+
+You may call it on the record, after re-constructing it lazily:
+
+> sizeOf . lazy
+>
+> lazy :: Complex a -> Complex a
+> lazy ~(r:+i) = r:+i
+-}
 sizeOf ::
    (Fold.Foldable f, Storable a) =>
    f a -> Int
